@@ -2,6 +2,6 @@
 fn ui_tests() {
     let t = trybuild::TestCases::new();
     t.pass("tests/ui/route_get.rs");
-    t.pass("tests/ui/async.rs");
     t.compile_fail("tests/ui/empty_path.rs");
+    t.compile_fail("tests/ui/glob.rs");
 }
