@@ -31,13 +31,10 @@ fn main() {
     let router = router![home, foo_bar_baz, bar_baz_qux];
     let _response: http::Response<String> = match router(request) {
         // Matched a route
-        Ok(Ok(resp)) => resp,
+        RouterResult::Handled(Ok(resp)) => resp,
         // There was an error
-        Ok(Err(_err)) => {
-            // convert err into an http::Response;
-            todo!()
-        }
+        RouterResult::Handled(Err(_))  |
         // No routes matched
-        Err(_request) => todo!(),
+        RouterResult::NotHandled(_) => panic!("request should have been handled")
     };
 }
